PylonError

Enum PylonError 

#[non_exhaustive]
pub enum PylonError { Msg(String), ShimCallFailed { op: &'static str, callsite: String, err_str: String, }, InvalidShimOutput { op: &'static str, detail: String, }, DlOpenFailed { path: OsString, source: String, }, ShimError(ShimError), }
Errors returned by this crate.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Msg(String)

A general error message produced by this crate.



ShimCallFailed

A shim call returned an error string.

Fields

op: &'static str

Logical shim operation name.

callsite: String

Rust callsite where the failing shim function was invoked.

err_str: String

Error message returned by the shim.



InvalidShimOutput

A shim call reported success but returned invalid output.

Fields

op: &'static str

Logical shim operation name.

detail: String

Description of which output invariant failed.



DlOpenFailed

The shim library could not be opened.

Fields

path: OsString

The attempted shim library path.

source: String


ShimError(ShimError)

A lower-level error reported while loading or validating the shim.